@@ -256,15 +256,15 @@ class MessageDialog(Dialog):
         self._command = command
         self._width = width
         self._alert = alert
-        self._default = (default,)
+        self._default = default
         self._padding = padding
         self._icon = icon
         self._localize = kwargs.get("localize")
 
         if buttons is None:
             self._buttons = [
-                f"{MessageCatalog.translate('Cancel')}:secondary",
-                f"{MessageCatalog.translate('OK')}:primary",
+                f"{MessageCatalog.translate('Cancel')}",
+                f"{MessageCatalog.translate('OK')}",
             ]
         else:
             self._buttons = buttons
@@ -303,11 +303,20 @@ class MessageDialog(Dialog):
 
         for i, button in enumerate(self._buttons[::-1]):
             cnf = button.split(":")
+            text = cnf[0]
+
+            is_default = False
+            if self._default is not None and text == self._default:
+                is_default = True
+            elif self._default is None and i == 0:
+                is_default = True
+
             if len(cnf) == 2:
-                text, bootstyle = cnf
+                bootstyle = cnf[1]
+            elif is_default:
+                bootstyle = 'primary'
             else:
-                text = cnf[0]
-                bootstyle = "secondary"
+                bootstyle = 'secondary'
 
             if self._localize == True:
                 text = MessageCatalog.translate(text)
@@ -318,14 +327,20 @@ class MessageDialog(Dialog):
             btn.lower()  # set focus traversal left-to-right
             button_list.append(btn)
 
-            if self._default is not None and text == self._default:
-                self._initial_focus = btn
-            elif self._default is None and i == 0:
+            if is_default:
                 self._initial_focus = btn
 
-        # bind default button to return key press and set focus
-        self._toplevel.bind("<Return>", lambda _, b=btn: b.invoke())
-        self._toplevel.bind("<KP_Enter>", lambda _, b=btn: b.invoke())
+            # bind default button to return key press and set focus
+            btn.bind("<Return>", lambda _, b=btn: b.invoke())
+            btn.bind("<KP_Enter>", lambda _, b=btn: b.invoke())
+
+        for index, btn in enumerate(button_list):
+            if index > 0:
+                nbtn = button_list[index - 1]
+                btn.bind('<Right>', lambda _, b=nbtn:b.focus_set())
+            if index < len(button_list) - 1:
+                nbtn = button_list[index + 1]
+                btn.bind('<Left>', lambda _, b=nbtn:b.focus_set())
 
         ttk.Separator(self._toplevel).pack(fill=X)
         frame.pack(side=BOTTOM, fill=X, anchor=S)
@@ -845,7 +860,7 @@ class DatePickerDialog:
 
     def _set_window_position(self):
         """Move the window the to bottom-right of the parent widget, or
-        the top-left corner of the master window if no parent is 
+        the top-left corner of the master window if no parent is
         provided.
         """
         if self.parent:
@@ -887,11 +902,11 @@ class FontDialog(Dialog):
     ![](../../assets/dialogs/querybox-get-font.png)
     """
 
-    def __init__(self, title="Font Selector", parent=None):
+    def __init__(self, title="Font Selector", parent=None, default_font="TkDefaultFont"):
         title = MessageCatalog.translate(title)
         super().__init__(parent=parent, title=title)
         self._style = ttk.Style()
-        self._default = font.nametofont("TkDefaultFont")
+        self._default = font.nametofont(default_font)
         self._actual = self._default.actual()
         self._size = ttk.Variable(value=self._actual["size"])
         self._family = ttk.Variable(value=self._actual["family"])
@@ -948,6 +963,9 @@ class FontDialog(Dialog):
         cancel_btn.pack(side=RIGHT, padx=5)
         cancel_btn.bind("<Return>", lambda _: cancel_btn.invoke())
 
+        self._toplevel.bind("<Escape>", func=lambda _:cancel_btn.invoke())
+        self._toplevel.protocol("WM_DELETE_WINDOW", func=cancel_btn.invoke)
+
     def _font_families_selector(self, master):
         container = ttk.Frame(master)
         container.pack(fill=BOTH, expand=YES, side=LEFT)
@@ -1126,6 +1144,7 @@ class FontDialog(Dialog):
         return self.result
 
     def _on_cancel(self):
+        self._result = None
         self._toplevel.destroy()
 
     def _update_font_preview(self, *_):
@@ -1189,6 +1208,7 @@ class Messagebox:
             buttons=["OK:primary"],
             icon=Icon.info,
             localize=True,
+            **kwargs
         )
         if "position" in kwargs:
             position = kwargs.pop("position")
@@ -1287,7 +1307,7 @@ class Messagebox:
         message,
         title=" ",
         parent=None,
-        buttons=["No:secondary", "Yes:primary"],
+        buttons=["No", "Yes"],
         alert=True,
         **kwargs,
     ):
@@ -1477,7 +1497,7 @@ class Messagebox:
             title=title,
             message=message,
             parent=parent,
-            buttons=["No", "Yes:primary"],
+            buttons=["No", "Yes"],
             alert=alert,
             localize=True,
             **kwargs,
@@ -1527,7 +1547,7 @@ class Messagebox:
             message=message,
             parent=parent,
             alert=alert,
-            buttons=["Cancel", "No", "Yes:primary"],
+            buttons=["Cancel", "No", "Yes"],
             localize=True,
             **kwargs,
         )
@@ -1576,7 +1596,7 @@ class Messagebox:
             message=message,
             parent=parent,
             alert=alert,
-            buttons=["Cancel", "Retry:primary"],
+            buttons=["Cancel", "Retry"],
             localize=True,
             **kwargs,
         )
