@@ -1,3 +1,5 @@
+from typing import Literal
+
 import ttkbootstrap as ttk
 from ttkbootstrap.constants import *
 from ttkbootstrap import utility
@@ -38,8 +40,11 @@ class ToolTip:
         self,
         widget,
         text="widget info",
+        justify: Literal["left", "center", "right"] = "left",
         bootstyle=None,
         wraplength=None,
+        delay=250,    # milliseconds
+        image=None,
         **kwargs,
     ):
         """
@@ -66,9 +71,13 @@ class ToolTip:
         """
         self.widget = widget
         self.text = text
+        self.justify = justify
+        self.image = image
         self.bootstyle = bootstyle
         self.wraplength = wraplength or utility.scale_size(self.widget, 300)
         self.toplevel = None
+        self.delay = delay
+        self.id = None
 
         # set keyword arguments
         kwargs["overrideredirect"] = True
@@ -90,10 +99,27 @@ class ToolTip:
         )
 
         # event binding
-        self.widget.bind("<Enter>", self.show_tip)
-        self.widget.bind("<Leave>", self.hide_tip)
+        self.widget.bind("<Enter>", self.enter)
+        self.widget.bind("<Leave>", self.leave)
         self.widget.bind("<Motion>", self.move_tip)
-        self.widget.bind("<ButtonPress>", self.hide_tip)
+        self.widget.bind("<ButtonPress>", self.leave)
+
+    def enter(self, event=None):
+        self.schedule()
+
+    def leave(self, event=None):
+        self.unschedule()
+        self.hide_tip()
+
+    def schedule(self):
+        self.unschedule()
+        self.id = self.widget.after(self.delay, self.show_tip)
+
+    def unschedule(self):
+        id = self.id
+        self.id = None
+        if id:
+            self.widget.after_cancel(id)
 
     def show_tip(self, *_):
         """Create a show the tooltip window"""
@@ -106,7 +132,9 @@ class ToolTip:
         lbl = ttk.Label(
             master=self.toplevel,
             text=self.text,
-            justify=LEFT,
+            image=self.image,
+            compound='bottom',
+            justify=self.justify,
             wraplength=self.wraplength,
             padding=10,
         )
