@@ -20,10 +20,11 @@ import math
 # meter imports
 from PIL import Image, ImageTk, ImageDraw
 from ttkbootstrap.style import Colors
+from ttkbootstrap.colorutils import contrast_color
 from ttkbootstrap import utility
-from ttkbootstrap.style import Bootstyle
+from ttkbootstrap.style import Bootstyle, Style
 
-M = 3 # meter image scale, higher number increases resolution
+M = 3  # meter image scale, higher number increases resolution
 
 TTK_WIDGETS = (
     ttk.Button,
@@ -94,13 +95,13 @@ class DateEntry(ttk.Frame):
     """
 
     def __init__(
-        self,
-        master=None,
-        dateformat=r"%x",
-        firstweekday=6,
-        startdate=None,
-        bootstyle="",
-        **kwargs,
+            self,
+            master=None,
+            dateformat=r"%x",
+            firstweekday=6,
+            startdate=None,
+            bootstyle="",
+            **kwargs,
     ):
         """
         Parameters:
@@ -169,7 +170,7 @@ class DateEntry(ttk.Frame):
             state = kwargs.pop("state")
             if state in ["readonly", "invalid"]:
                 self.entry.configure(state=state)
-            elif state == "disabled":
+            elif state in ("disabled", "normal"):
                 self.entry.configure(state=state)
                 self.button.configure(state=state)
             else:
@@ -250,68 +251,365 @@ class DateEntry(ttk.Frame):
         self.entry.focus_force()
 
 
-class Floodgauge(Progressbar):
-    """A widget that shows the status of a long-running operation
-    with an optional text indicator.
+class Floodgauge(tk.Canvas):
+    """
+    A canvas-based widget that displays progress in determinate or indeterminate mode,
+    styled using ttkbootstrap's color system.
 
-    Similar to the `ttk.Progressbar`, this widget can operate in
-    two modes. *determinate* mode shows the amount completed
-    relative to the total amount of work to be done, and
-    *indeterminate* mode provides an animated display to let the
-    user know that something is happening.
+    This widget mimics the behavior of ttk.Progressbar with additional features:
+    - Canvas-based drawing for full styling control
+    - Bounce-style animation for indeterminate mode
+    - Lightened trough color based on the bootstyle
+    - Support for variable and textvariable bindings
+    - Auto-updating label based on mask or textvariable
+    - Theme-reactive color updates via <<ThemeChanged>> event
 
-    Variable are generated automatically for this widget and can be
-    linked to other widgets by referencing them via the
-    `textvariable` and `variable` attributes.
+    Parameters:
+        master (Widget, optional):
+            Parent widget.
 
-    ![](../../assets/widgets/floodgauge.gif)
+        value (int):
+            Initial value of the progress bar.
 
-    Examples:
+        maximum (int):
+            The maximum value for the determinate range.
 
-        ```python
-        import ttkbootstrap as ttk
-        from ttkbootstrap.constants import *
+        mode (str):
+            'determinate' or 'indeterminate' mode.
 
-        app = ttk.Window(size=(500, 500))
+        mask (str, optional):
+            A string with a '{}' placeholder for formatted text output, e.g. 'Progress: {}%'.
 
-        gauge = ttk.Floodgauge(
-            bootstyle=INFO,
-            font=(None, 24, 'bold'),
-            mask='Memory Used {}%',
-        )
-        gauge.pack(fill=BOTH, expand=YES, padx=10, pady=10)
+        text (str, optional):
+            A static fallback label (used if no mask is specified).
 
-        # autoincrement the gauge
-        gauge.start()
+        font (Font or tuple):
+            The font used for the label (default: Helvetica 14 bold).
 
-        # stop the autoincrement
-        gauge.stop()
+        bootstyle (str):
+            A ttkbootstrap style keyword such as 'primary', 'info', etc.
 
-        # manually update the gauge value
-        gauge.configure(value=25)
+        orient (str):
+            'horizontal' or 'vertical' orientation.
 
-        # increment the value by 10 steps
-        gauge.step(10)
+        length (int):
+            The long dimension of the widget (width if horizontal, height if vertical). Defaults to 200.
 
-        app.mainloop()
-        ```
+        thickness (int):
+            The short axis of the widget (height if horizontal, width if vertical). Defaults to 50.
+
+        variable (tk.IntVar, optional):
+            Bound variable for the current value.
+
+        textvariable (tk.StringVar, optional):
+            Bound variable for the display label.
     """
 
     def __init__(
         self,
         master=None,
-        cursor=None,
-        font=None,
-        length=None,
-        maximum=100,
-        mode=DETERMINATE,
-        orient=HORIZONTAL,
-        bootstyle=PRIMARY,
-        takefocus=False,
-        text=None,
         value=0,
+        maximum=100,
+        mode="determinate",
         mask=None,
-        **kwargs,
+        text="",
+        font=("Helvetica", 12),
+        bootstyle="primary",
+        orient="horizontal",
+        length=200,
+        thickness=50,
+        **kwargs
+    ):
+        self.variable = kwargs.pop("variable", tk.IntVar(value=value))
+        self.textvariable = kwargs.pop("textvariable", tk.StringVar(value=text))
+
+        self.length = length
+        self.thickness = thickness
+        self.orient = orient
+        canvas_kwargs = dict(highlightthickness=0, **kwargs)
+
+        if self.orient == "horizontal":
+            canvas_kwargs.update(width=self.length, height=self.thickness)
+        else:
+            canvas_kwargs.update(width=self.thickness, height=self.length)
+
+        super().__init__(master, **canvas_kwargs)
+
+        self.variable.trace_add("write", lambda *_: self._on_var_change())
+        self.textvariable.trace_add("write", lambda *_: self._on_text_change())
+
+        self.value = self.variable.get()
+        self.text = self.textvariable.get()
+        self.maximum = maximum
+        self.mode = mode
+        self.mask = mask
+        self.font = font
+        self._step_size = 1
+        self._running = False
+        self._after_id = None
+        self._pulse_pos = 0
+        self._pulse_direction = 1
+        self._bootstyle = bootstyle
+
+        self._update_theme_colors()
+
+        self.bind("<Configure>", self._on_resize)
+        self.bind("<<ThemeChanged>>", lambda e: self._update_theme_colors())
+        self._draw()
+
+    def _update_theme_colors(self):
+        style = Style.get_instance()
+        self.bar_color = style.colors.get(self._bootstyle)
+        self.trough_color = Colors.update_hsv(self.bar_color, 0, -0.5, 0.3)
+        self.text_color = contrast_color(self.bar_color, 'hex')
+        self._draw()
+
+    def _on_resize(self, event):
+        if self.orient == "horizontal":
+            self.length = event.width
+            self.thickness = event.height
+        else:
+            self.length = event.height
+            self.thickness = event.width
+        self._draw()
+
+
+    def _draw(self):
+        self.delete("all")
+        w = self.winfo_width()
+        h = self.winfo_height()
+
+        self.create_rectangle(0, 0, w, h, fill=self.trough_color, width=0)
+
+        if self.mode == "determinate":
+            ratio = max(0, min(1, self.value / self.maximum))
+            if self.orient == "horizontal":
+                fill = int(ratio * w)
+                self.create_rectangle(0, 0, fill, h, fill=self.bar_color, width=0)
+            else:
+                fill = int(ratio * h)
+                self.create_rectangle(0, h - fill, w, h, fill=self.bar_color, width=0)
+        else:
+            if self.orient == "horizontal":
+                pulse_width = max(10, int(w * 0.2))
+                x = self._pulse_pos
+                self.create_rectangle(x, 0, x + pulse_width, h, fill=self.bar_color, width=0)
+            else:
+                pulse_height = max(10, int(h * 0.2))
+                y = self._pulse_pos
+                self.create_rectangle(0, y - pulse_height, w, y, fill=self.bar_color, width=0)
+
+        if self.mask:
+            label = self.mask.format(int(self.value))
+            self.textvariable.set(label)
+        elif self.textvariable:
+            label = self.textvariable.get()
+        else:
+            label = self.text
+
+        if label:
+            self.create_text(
+                w // 2,
+                h // 2,
+                text=label,
+                font=self.font,
+                fill=self.text_color,
+                anchor="center"
+            )
+
+    def _on_var_change(self):
+        self.value = self.variable.get()
+        self._draw()
+
+    def _on_text_change(self):
+        self.text = self.textvariable.get()
+        self._draw()
+
+    def step(self, amount=1):
+        self.value = (self.value + amount) % (self.maximum + 1)
+        self.variable.set(self.value)
+        self._draw()
+
+    def start(self, step_size=None, interval=None):
+        if self.mode == "indeterminate":
+            self._step_size = step_size if step_size is not None else 8
+            interval = interval if interval is not None else 20
+        else:
+            self._step_size = step_size if step_size is not None else 1
+            interval = interval if interval is not None else 50
+
+        self._running = True
+        self._pulse_direction = 1
+        self._run_animation(interval)
+
+    def stop(self):
+        self._running = False
+        if self._after_id:
+            self.after_cancel(self._after_id)
+            self._after_id = None
+
+    def _run_animation(self, interval):
+        if not self._running:
+            return
+
+        if self.mode == "indeterminate":
+            self._animate_indeterminate(interval)
+        else:
+            self.step(self._step_size)
+            self._after_id = self.after(interval, lambda: self._run_animation(interval))
+
+    def _animate_indeterminate(self, interval):
+        if not self._running:
+            return
+
+        if self.orient == "horizontal":
+            w = self.winfo_width()
+            pulse_width = max(10, int(w * 0.2))
+            max_pos = w - pulse_width
+            self._pulse_pos += self._step_size * self._pulse_direction
+            if self._pulse_pos >= max_pos:
+                self._pulse_pos = max_pos
+                self._pulse_direction = -1
+            elif self._pulse_pos <= 0:
+                self._pulse_pos = 0
+                self._pulse_direction = 1
+        else:
+            h = self.winfo_height()
+            pulse_height = max(10, int(h * 0.2))
+            max_pos = h
+            self._pulse_pos += self._step_size * self._pulse_direction
+            if self._pulse_pos >= max_pos:
+                self._pulse_pos = max_pos
+                self._pulse_direction = -1
+            elif self._pulse_pos <= pulse_height:
+                self._pulse_pos = pulse_height
+                self._pulse_direction = 1
+
+        self._draw()
+        self._after_id = self.after(interval, lambda: self._animate_indeterminate(interval))
+
+    def configure(self, cnf=None, **kwargs):
+        if cnf is not None and not kwargs:
+            custom = {
+                "value": ("value", "value", "Value", self.variable.get()),
+                "maximum": ("maximum", "maximum", "Maximum", self.maximum),
+                "mask": ("mask", "mask", "Mask", self.mask),
+                "text": ("text", "text", "Text", self.textvariable.get()),
+                "font": ("font", "font", "Font", self.font),
+                "bootstyle": ("bootstyle", "bootstyle", "Bootstyle", self._bootstyle),
+                "variable": ("variable", "variable", "Variable", str(self.variable)),
+                "textvariable": ("textvariable", "textvariable", "Textvariable", str(self.textvariable)),
+                "length": ("length", "length", "Length", self.length),
+                "thickness": ("thickness", "thickness", "Thickness", self.thickness),
+            }
+            if cnf in custom:
+                return custom[cnf]
+            else:
+                raise tk.TclError(f"unknown option '{cnf}'")
+
+        if "value" in kwargs:
+            self.value = kwargs.pop("value")
+            self.variable.set(self.value)
+        if "maximum" in kwargs:
+            self.maximum = kwargs.pop("maximum")
+        if "mask" in kwargs:
+            self.mask = kwargs.pop("mask")
+        if "text" in kwargs:
+            self.text = kwargs.pop("text")
+            self.textvariable.set(self.text)
+        if "font" in kwargs:
+            self.font = kwargs.pop("font")
+        if "bootstyle" in kwargs:
+            self._bootstyle = kwargs.pop("bootstyle")
+            self._update_theme_colors()
+        if "length" in kwargs:
+            self.length = kwargs.pop("length")
+            if self.orient == "horizontal":
+                self.configure(width=self.length)
+            else:
+                self.configure(height=self.length)
+        if "thickness" in kwargs:
+            self.thickness = kwargs.pop("thickness")
+            if self.orient == "horizontal":
+                self.configure(height=self.thickness)
+            else:
+                self.configure(width=self.thickness)
+        if "variable" in kwargs:
+            self.variable = kwargs.pop("variable")
+            self.variable.trace_add("write", lambda *_: self._on_var_change())
+        if "textvariable" in kwargs:
+            self.textvariable = kwargs.pop("textvariable")
+            self.textvariable.trace_add("write", lambda *_: self._on_text_change())
+
+        super().configure(**kwargs)
+        self._draw()
+
+    def cget(self, key):
+        if key == "value":
+            return self.variable.get()
+        if key == "text":
+            return self.textvariable.get()
+        if key == "maximum":
+            return self.maximum
+        if key == "mask":
+            return self.mask
+        if key == "bootstyle":
+            return self._bootstyle
+        if key == "font":
+            return self.font
+        if key == "length":
+            return self.length
+        if key == "thickness":
+            return self.thickness
+        if key == "variable":
+            return str(self.variable)
+        if key == "textvariable":
+            return str(self.textvariable)
+        return super().cget(key)
+
+    def keys(self):
+        return [
+            "value", "maximum", "mask", "text", "font",
+            "bootstyle", "length", "thickness", "variable", "textvariable"
+        ]
+
+    def items(self):
+        return {k: self.cget(k) for k in self.keys()}.items()
+
+    __getitem__ = lambda self, key: self.cget(key)
+    __setitem__ = lambda self, key, value: self.configure(**{key: value})
+
+
+class FloodgaugeLegacy(Progressbar):
+    """
+    DEPRECATED: This widget is retained for backward compatibility. You may
+    use this is you have an issues with the canvas-based widget.
+
+    Use the canvas-based `Floodgauge` widget instead for:
+    - Full control over styling and draw order
+    - Support for theme responsiveness
+    - Animated indeterminate mode
+    - Automatic label updates with `mask` or `textvariable`
+
+    This legacy version is based on `ttk.Progressbar` and does not support
+    the same level of styling or animation flexibility.
+    """
+
+    def __init__(
+            self,
+            master=None,
+            cursor=None,
+            font=None,
+            length=None,
+            maximum=100,
+            mode=DETERMINATE,
+            orient=HORIZONTAL,
+            bootstyle=PRIMARY,
+            takefocus=False,
+            text=None,
+            value=0,
+            mask=None,
+            **kwargs,
     ):
         """
         Parameters:
@@ -385,6 +683,8 @@ class Floodgauge(Progressbar):
             self._textvariable = kwargs.pop('textvariable')
         else:
             self._textvariable = tk.StringVar(value=text)
+
+        self._textvariable.trace_add("write", self._set_widget_text)
         self._bootstyle = bootstyle
         self._font = font or "helvetica 10"
         self._mask = mask
@@ -513,7 +813,6 @@ class Floodgauge(Progressbar):
         if self.cget('variable') != value:
             self.configure(variable=self._variable)
 
-
 class Meter(ttk.Frame):
     """A radial meter that can be used to show progress of long
     running operations or the amount of work completed; can also be
@@ -583,28 +882,29 @@ class Meter(ttk.Frame):
     """
 
     def __init__(
-        self,
-        master=None,
-        bootstyle=DEFAULT,
-        arcrange=None,
-        arcoffset=None,
-        amounttotal=100,
-        amountused=0,
-        wedgesize=0,
-        metersize=200,
-        metertype=FULL,
-        meterthickness=10,
-        showtext=True,
-        interactive=False,
-        stripethickness=0,
-        textleft=None,
-        textright=None,
-        textfont="-size 20 -weight bold",
-        subtext=None,
-        subtextstyle=DEFAULT,
-        subtextfont="-size 10",
-        stepsize=1,
-        **kwargs,
+            self,
+            master=None,
+            bootstyle=DEFAULT,
+            arcrange=None,
+            arcoffset=None,
+            amounttotal=100,
+            amountused=0,
+            amountformat="{:.0f}",
+            wedgesize=0,
+            metersize=200,
+            metertype=FULL,
+            meterthickness=10,
+            showtext=True,
+            interactive=False,
+            stripethickness=0,
+            textleft=None,
+            textright=None,
+            textfont="-size 20 -weight bold",
+            subtext=None,
+            subtextstyle=DEFAULT,
+            subtextfont="-size 10",
+            stepsize=1,
+            **kwargs,
     ):
         """
         Parameters:
@@ -626,6 +926,9 @@ class Meter(ttk.Frame):
                 The current value of the meter; displayed in a center label
                 if the `showtext` property is set to True.
 
+            amountformat (str):
+                The format used to display the `amountused` value. Default is "{:.0f}"
+
             wedgesize (int):
                 Sets the length of the indicator wedge around the arc. If
                 greater than 0, this wedge is set as an indicator centered
@@ -692,19 +995,21 @@ class Meter(ttk.Frame):
 
         # widget variables
         self.amountusedvar = tk.IntVar(value=amountused)
-        self.amountusedvar.trace_add("write", self._draw_meter)
+        self.amountusedvar.trace_add("write", self._update_meter)
+        self.amountuseddisplayvar = tk.StringVar(value=amountformat.format(amountused))
         self.amounttotalvar = tk.IntVar(value=amounttotal)
         self.labelvar = tk.StringVar(value=subtext)
 
         # misc settings
+        self._amountformat = amountformat
         self._set_arc_offset_range(metertype, arcoffset, arcrange)
-        self._towardsmaximum = True
+        self._towards_maximum = True
         self._metersize = utility.scale_size(self, metersize)
         self._meterthickness = utility.scale_size(self, meterthickness)
         self._stripethickness = stripethickness
         self._showtext = showtext
         self._wedgesize = wedgesize
-        self._stepsize = stepsize        
+        self._stepsize = stepsize
         self._textleft = textleft
         self._textright = textright
         self._textfont = textfont
@@ -717,6 +1022,11 @@ class Meter(ttk.Frame):
 
         self._setup_widget()
 
+    def _update_meter(self, *_):
+        self._draw_meter()
+        amount_used = self.amountusedvar.get()
+        self.amountuseddisplayvar.set(self._amountformat.format(amount_used))
+
     def _setup_widget(self):
         self.meterframe = ttk.Frame(
             master=self, width=self._metersize, height=self._metersize
@@ -733,7 +1043,7 @@ class Meter(ttk.Frame):
         )
         self.textcenter = ttk.Label(
             master=self.textframe,
-            textvariable=self.amountusedvar,
+            textvariable=self.amountuseddisplayvar,
             bootstyle=(self._bootstyle, "meter"),
             font=self._textfont,
         )
@@ -750,6 +1060,7 @@ class Meter(ttk.Frame):
             text=self._subtext,
             bootstyle=(self._subtextstyle, "metersubtxt"),
             font=self._subtextfont,
+            textvariable=self.labelvar,
         )
 
         self.bind("<<ThemeChanged>>", self._on_theme_change)
@@ -853,7 +1164,7 @@ class Meter(ttk.Frame):
             self._draw_solid_meter(draw)
 
         self._meterimage = ImageTk.PhotoImage(
-            img.resize((self._metersize, self._metersize), Image.CUBIC)
+            img.resize((self._metersize, self._metersize), Image.BICUBIC)
         )
         self.indicator.configure(image=self._meterimage)
 
@@ -966,12 +1277,12 @@ class Meter(ttk.Frame):
             factor = 360 + degs - self._arcoffset
 
         # clamp the value between 0 and `amounttotal`
-        amounttotal = self.amounttotalvar.get() 
+        amounttotal = self.amounttotalvar.get()
         lastused = self.amountusedvar.get()
         amountused = (amounttotal / self._arcrange * factor)
 
         # calculate amount used given stepsize
-        if amountused > self._stepsize//2:
+        if amountused > self._stepsize // 2:
             amountused = amountused // self._stepsize * self._stepsize + self._stepsize
         else:
             amountused = 0
@@ -1072,9 +1383,7 @@ class Meter(ttk.Frame):
         if "metertype" in kwargs:
             self._metertype = kwargs.pop("metertype")
         if "meterthickness" in kwargs:
-            self._meterthickness = self.scale_size(
-                kwargs.pop("meterthickness")
-            )
+            self._meterthickness = kwargs.pop("meterthickness")
         if "stripethickness" in kwargs:
             self._stripethickness = kwargs.pop("stripethickness")
         if "subtext" in kwargs:
@@ -1148,15 +1457,19 @@ class Meter(ttk.Frame):
             delta (int):
                 The amount to change the indicator.
         """
-        amountused = self.amountusedvar.get()
-        amounttotal = self.amounttotalvar.get()
-        if amountused >= amounttotal:
-            self._towardsmaximum = True
-            self.amountusedvar.set(amountused - delta)
-        elif amountused <= 0:
-            self._towardsmaximum = False
-            self.amountusedvar.set(amountused + delta)
-        elif self._towardsmaximum:
-            self.amountusedvar.set(amountused - delta)
+        amount_used = self.amountusedvar.get()
+        amount_total = self.amounttotalvar.get()
+
+        if self._towards_maximum:
+            amount_updated = amount_used + delta
         else:
-            self.amountusedvar.set(amountused + delta)
+            amount_updated = amount_used - delta
+
+        if amount_updated >= amount_total:
+            self._towards_maximum = False
+            self.amountusedvar.set(amount_total - (amount_updated - amount_total))
+        elif amount_updated < 0:
+            self._towards_maximum = True
+            self.amountusedvar.set(abs(amount_updated))
+        else:
+            self.amountusedvar.set(amount_updated)
\ No newline at end of file
