@@ -42,12 +42,18 @@ def apply_class_bindings(window: tkinter.Widget):
 
     window.unbind_class("TButton", "<Key-space>")
 
-    def on_button_enter(event):
-        widget = window.nametowidget(event.widget)
-        widget.invoke()
+    def button_default_binding(event):
+        """The default keybind on a button when the return or enter key
+        is pressed and the button has focus or is the default button."""
+        try:
+            widget = window.nametowidget(event.widget)
+            widget.invoke()
+        except KeyError:
+            window.tk.call(event.widget, 'invoke')
 
-    window.bind_class("TButton", "<Key-Return>", on_button_enter)
-    window.bind_class("TButton", "<KP_Enter>", on_button_enter)
+    window.bind_class("TButton", "<Key-Return>", button_default_binding,
+                      add="+")
+    window.bind_class("TButton", "<KP_Enter>", button_default_binding, add="+")
 
 
 def apply_all_bindings(window: tkinter.Widget):
@@ -95,7 +101,7 @@ def on_select_all(event):
     """Callback to select all text in the input widget when an event is
     executed."""
     widget = event.widget
-    if widget.__class__.__name__ == "Text":
+    if widget.__class__.__name__ in ("Text", "ScrolledText"):
         widget.tag_add(SEL, "1.0", END)
         widget.mark_set(INSERT, END)
         widget.see(END)
@@ -137,6 +143,7 @@ class Window(tkinter.Tk):
         transient=None,
         overrideredirect=False,
         alpha=1.0,
+        **kwargs,
     ):
         """
         Parameters:
@@ -209,11 +216,15 @@ class Window(tkinter.Tk):
                 On Windows, specifies the alpha transparency level of the
                 toplevel. Where not supported, alpha remains at 1.0. Internally,
                 this is processed as `Toplevel.attributes('-alpha', alpha)`.
+
+            **kwargs:
+                Any other keyword arguments that are passed through to tkinter.Tk() constructor
+                List of available keywords available at: https://docs.python.org/3/library/tkinter.html#tkinter.Tk
         """
         if hdpi:
             utility.enable_high_dpi_awareness()
 
-        super().__init__()
+        super().__init__(**kwargs)
         self.winsys = self.tk.call('tk', 'windowingsystem')
 
         if scaling is not None:
@@ -257,16 +268,16 @@ class Window(tkinter.Tk):
             width, height = resizable
             self.resizable(width, height)
         
+        if alpha is not None:
+            if self.winsys == 'x11':
+                self.wait_visibility(self)
+            self.attributes("-alpha", alpha)
+        
         if transient is not None:
             self.transient(transient)
         
         if overrideredirect:
             self.overrideredirect(1)
-        
-        if alpha is not None:
-            if self.winsys == 'x11':
-                self.wait_visibility(self)
-            self.attributes("-alpha", alpha)
 
         apply_class_bindings(self)
         apply_all_bindings(self)
@@ -278,6 +289,11 @@ class Window(tkinter.Tk):
         """Return a reference to the `ttkbootstrap.style.Style` object."""
         return self._style
 
+    def destroy(self):
+        """Destroy the window and all its children."""
+        self._style.instance = None
+        super().destroy()
+
     def place_window_center(self):
         """Position the toplevel in the center of the screen. Does not
         account for titlebar height."""
@@ -408,9 +424,6 @@ class Toplevel(tkinter.Toplevel):
 
         super().__init__(**kwargs)
         self.winsys = self.tk.call('tk', 'windowingsystem')
-        
-        if iconify:
-            self.iconify()
 
         if iconphoto != '':
             try:
@@ -444,6 +457,14 @@ class Toplevel(tkinter.Toplevel):
             width, height = resizable
             self.resizable(width, height)
         
+        if alpha is not None:
+            if self.winsys == 'x11':
+                self.wait_visibility(self)
+            self.attributes("-alpha", alpha)
+        
+        if iconify:
+            self.iconify()
+        
         if transient is not None:
             self.transient(transient)
         
@@ -460,11 +481,6 @@ class Toplevel(tkinter.Toplevel):
         if toolwindow:
             if self.winsys == 'win32':
                 self.attributes("-toolwindow", 1)
-        
-        if alpha is not None:
-            if self.winsys == 'x11':
-                self.wait_visibility(self)
-            self.attributes("-alpha", alpha)
 
     @property
     def style(self):
